@@ -97,6 +97,10 @@ class PlatformJson(pydantic.BaseModel):
         
     def __init__(self, path: Union[str, pathlib.Path]) -> None:
         super().__init__(path=path)
+        if self.path.exists():
+            logger.debug("Loading from existing %s", self.path.name)
+        else:
+            logger.debug("Creating new %s", self.path.name)
         self.load_from_existing()
         
     def __str__(self):
@@ -125,10 +129,13 @@ class PlatformJson(pydantic.BaseModel):
             # fetch fields from disk before writing, in case another process updated the
             # file since we last read it
             self.load_from_existing()
-            
+        
+        if getattr(self, name, None) == value:
+            return
+        
         _ = super().__setattr__(name, value)
         
-        logger.info("Updated %s.%s = %s", self.path.name, name, value)
+        logger.debug("Updated %s.%s = %s", self.path.name, name, value)
             
         if self.file_sync:
             self.write()
