@@ -429,12 +429,13 @@ class Session:
     
     @property
     def platform_json(self) -> PlatformJson:
-        """Platform D1 json on npexp."""
-        with contextlib.suppress(AttributeError):
-            return self._platform_json
-        self._platform_json = PlatformJson(self.npexp_path)
-        update_from_session(self._platform_json, self)
-        return self.platform_json
+        """Platform D1 json on npexp.
+        
+        Not cached so we always get the current contents on disk.
+        """
+        platform_json = PlatformJson(self.npexp_path)
+        update_from_session(platform_json, self)
+        return platform_json
     
     def fix_platform_json(self, path_or_obj: Optional[pathlib.Path | PlatformJson] = None):
         if not path_or_obj:
